=========
Templates
=========

Templates to generate python scripts.

User's Guide
------------

The :py:class:`~abqpy.template.ScriptTemplate` class provides a simple interface to generate python scripts from
templates.

CompressionTemplate
-------------------

.. autoclass:: abqpy.template.CompressionTemplate


ScriptTemplate
--------------

.. autoclass:: abqpy.template.ScriptTemplate
   :members:
   :special-members: __init__
